import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;

public class AccountApp {

    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";

    private Dao<Account, Integer> accountDao;

    private boolean programActive = true;
    Console console = new Console();

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "");
            // setup our  DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            processData();

            System.out.println("\n\nIt seems to have worked\n\n");
        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    /**
     * Setup our  DAOs
     */
    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }

    /**
     * Read and write some example data.
     */
    private void processData() throws Exception {
        console.welcomeScreen();
        while (programActive) {
            menuSelect();
        }

    }

    public void menuSelect() throws Exception {
        console.menuOptions();
        switch (console.getMenuSelection()) {
            case "c":
                createAccount(console.getName(), console.getPassword());
                break;
            case "v":
                viewAccount(console.getId());
                break;
            case "n":
                updateAccountName(console.getId(), console.getName());
                break;
            case "p":
                updateAccountPassword(console.getId(),console.getPassword());
                break;
            case "d":
                deleteAccount(console.getId());
                break;
            case "exit":
                exit();
                break;
        }
    }

    public void createAccount(String name, String password) throws Exception {
        Account account = new Account(name);
        accountDao.create(account);
        account.setPassword(password);
        accountDao.update(account);
    }

    public void viewAccount(int id) throws Exception {
        Account account = accountDao.queryForId(id);
        console.printAccountDetails(account.getId(), account.getName(), account.getPassword());
    }

    public void updateAccountName(int id, String name) throws Exception {
        Account account = accountDao.queryForId(id);
        account.setName(name);
        accountDao.update(account);
    }

    public void updateAccountPassword(int id, String password) throws Exception {
        Account account = accountDao.queryForId(id);
        account.setPassword(password);
        accountDao.update(account);
    }

    public void deleteAccount(int id) throws Exception{
        Account account = accountDao.queryForId(id);
        accountDao.deleteById(id);
    }

    public void exit() {
        programActive = false;
        console.exitMessage();
    }
}